@@ -1,4 +1,4 @@
-# Copyright 2015 Jeffrey Kegler
+# Copyright 2018 Jeffrey Kegler
 # This file is part of Marpa::R2.  Marpa::R2 is free software: you can
 # redistribute it and/or modify it under the terms of the GNU Lesser
 # General Public License as published by the Free Software Foundation,
@@ -15,7 +15,7 @@
 
 package Marpa::R2::Internal::License;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -24,7 +24,7 @@ use Fatal qw(open close read);
 use File::Spec;
 use Text::Diff ();
 
-my $copyright_line = q{Copyright 2015 Jeffrey Kegler};
+my $copyright_line = q{Copyright 2018 Jeffrey Kegler};
 ( my $copyright_line_in_tex = $copyright_line )
     =~ s/ ^ Copyright \s /Copyright \\copyright\\ /xms;
 
@@ -90,7 +90,7 @@ version 3 should be in a file named "COPYING.LESSER".
 END_OF_STRING
 
 my $texi_copyright = <<'END_OF_TEXI_COPYRIGHT';
-Copyright @copyright{} 2015 Jeffrey Kegler.
+Copyright @copyright{} 2018 Jeffrey Kegler.
 END_OF_TEXI_COPYRIGHT
 
 my $fdl_license = <<'END_OF_FDL_LANGUAGE';
@@ -304,8 +304,10 @@ my %files_by_type = (
     'html/script/marpa_r2_html_score'  => gen_license_problems_in_perl_file(),
     'html/t/fmt_t_data/expected1.html' => \&ignored,
     'html/t/fmt_t_data/expected2.html' => \&ignored,
+    'html/t/fmt_t_data/expected3.html' => \&ignored,
     'html/t/fmt_t_data/input1.html'    => \&trivial,
     'html/t/fmt_t_data/input2.html'    => \&trivial,
+    'html/t/fmt_t_data/input3.html'    => \&trivial,
     'html/t/fmt_t_data/score_expected1.html' => \&trivial,
     'html/t/fmt_t_data/score_expected2.html' => \&trivial,
     'html/t/no_tang.html'                    => \&ignored,
